<h1 align="center">i18Next Translator</h1>

<p align="center">The i18Next Translator is a specialized tool designed to simplify and automate the localization process for applications utilizing the i18next internationalization framework. This tool streamlines the translation of your i18next resource files, ensuring efficient and accurate localization across multiple languages.</p>

<p align="center">
    <a href="https://pypi.org/project/i18trans/"><img src="https://raw.githubusercontent.com/hemucode/i18trans/refs/heads/main/json.png" alt="PyPI Version"></a>
    <a href="https://www.codehemu.com/p/donate.html"><img src="https://img.shields.io/badge/-buy_me_a%C2%A0beer-gray?logo=buy-me-a-coffee" alt="Donate"></a>

</p>
## Getting Started

### Prerequisites

- Python: 3.6-3.12

### Installation and Usage

#### Installing via [PyPI](https://pypi.org/project/i18trans/)

You can install this project using PyPI:

```
$ pip install i18trans
```

Then to run it, windows terminal:

```
C:\Users\user> python -m i18trans
```
> If you have more than one version of Python installed, you can use `python -m i18trans` instead of `i18trans`.

Then to run it, execute the following in the terminal:

```
$ i18trans
```
or





#### Installing via [GitHub](https://github.com/hemucode/i18trans)

```
$ git clone https://github.com/hemucode/i18trans.git
$ cd i18trans
$ python setup.py install
```

Then to run it, execute the following in the terminal:

```
$ i18trans
```

#### Running Locally via [Github](https://github.com/hemucode/i18trans) (no install)

You can run this project locally by following these steps:

1. Clone/download the [repo](https://github.com/hemucode/i18trans)
2. Open cmd/terminal and cd into the project's root folder
3. Execute `python -m pip install -r requirements.txt`
4. Execute `python -m i18trans` to run the application


_Easy._

